spawn_shell

Function spawn_shell 

pub async fn spawn_shell() -> Result<(UnixPtyMaster, UnixPtyChild)>
Create a PTY with the default configuration and spawn a shell.

This is a convenience function that uses the platform’s native PTY system.

Errors

Returns an error if PTY creation or shell spawning fails.