Module traits

Module traits 

Core traits for PTY abstraction.

This module defines the primary traits used by the rust-pty crate:

  • PtyMaster: The master side of a PTY (for reading/writing to the terminal).
  • PtyChild: Handle for the spawned child process.
  • PtySystem: Factory for creating PTY sessions.

Enums

ExitStatus
Exit status of a child process.

Traits

PtyChild
Handle for a child process spawned in a PTY.
PtyMaster
The master side of a pseudo-terminal.
PtySystem
Factory trait for creating PTY sessions.