ExitStatus

Enum ExitStatus 

pub enum ExitStatus {
    Exited(i32),
    Signaled(i32),
}
Exit status of a child process.

Variants



Exited(i32)

The process exited normally with the given exit code.



Signaled(i32)

The process was terminated by a signal (Unix only).

Implementations

Source

impl ExitStatus

pub const fn success(&self) -> bool

Check if the process exited successfully (exit code 0).

pub const fn code(&self) -> Option<i32>

Get the exit code, if available.

pub const fn signal(&self) -> Option<i32>

Get the signal number that terminated the process (Unix only).